==> cscec5b-wzxt-impl-3.0.0-20210318.084200-154-sources.jar: com/ejianc/business/wzxt/bean/ExitEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.wzxt.bean.ExitDetailEntity;
/**
 * 退场单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_exit")
public class ExitEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目
    @TableField(value="project_source_id")
    private java.lang.String projectSourceId; // 项目来源ID
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_source_id")
    private java.lang.String orgSourceId; // 组织来源ID
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private java.lang.Long parentOrgId; // 上级组织
    @TableField(value="parent_org_source_id")
    private java.lang.String parentOrgSourceId; // 上级组织来源ID
    @TableField(value="contract_id")
    private java.lang.String contractId; // 合同主键
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 供应商名称
    @TableField(value="supplier_source_id")
    private java.lang.String supplierSourceId; // 供应商来源ID
    @TableField(value="exit_date")
    private java.util.Date exitDate; // 退场日期
    @TableField(value="confirm_date")
    private java.util.Date confirmDate; // 确认日期
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="confirm_flag")
    private java.lang.Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 经办人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 经办人名称
    @TableField(value="confirmer_id")
    private java.lang.Long confirmerId; // 确认人
    @TableField(value="confirmer_name")
    private java.lang.String confirmerName; // 确认人名称
    @TableField(value="exit_note")
    private java.lang.String exitNote; // 退场说明
    @TableField(value="confirm_note")
    private java.lang.String confirmNote; // 确认说明
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="def1")
    private java.lang.String def1; // 
    @TableField(value="def2")
    private java.lang.String def2; // 
    @TableField(value="def3")
    private java.lang.String def3; // 
    @TableField(value="def4")
    private java.lang.String def4; // 
    @TableField(value="def5")
    private java.lang.String def5; // 
    @TableField(value="apply_id")
    private java.lang.Long applyId; // 申请单ID
    @TableField(value="save_state")
    private java.lang.Integer saveState; // 保存状态（0-暂存态，1-保存态）
    @TableField(value="use_state")
    private java.lang.Integer useState; // 推送NC状态，0-未推送，1-已推送
    @TableField(value="push_user_id")
    private java.lang.Long pushUserId; // 推送人主键
    @TableField(value="push_user_source_id")
    private java.lang.String pushUserSourceId; // 推送人来源ID
    @TableField(value="push_user_name")
    private java.lang.String pushUserName; // 推送人名称
    @TableField(value="isaddrecord")
    private java.lang.String isaddrecord; // 是否补录，0-否，1-是
    @TableField(value="addrcdreson")
    private java.lang.String addrcdreson; // 补录原因
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="exitDetailService",pidName = "exitId")
    private List<ExitDetailEntity> exitDetail = new ArrayList<>(); // 退场单明细


    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目来源ID
     */
    public java.lang.String getProjectSourceId() {
        return projectSourceId;
    }

    /**
     * 项目来源ID
     */
    public void setProjectSourceId(java.lang.String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织来源ID
     */
    public java.lang.String getOrgSourceId() {
        return orgSourceId;
    }

    /**
     * 组织来源ID
     */
    public void setOrgSourceId(java.lang.String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织
     */
    public java.lang.Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织
     */
    public void setParentOrgId(java.lang.Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织来源ID
     */
    public java.lang.String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    /**
     * 上级组织来源ID
     */
    public void setParentOrgSourceId(java.lang.String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    /**
     * 合同主键
     */
    public java.lang.String getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(java.lang.String contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 设备供应商
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 供应商来源ID
     */
    public java.lang.String getSupplierSourceId() {
        return supplierSourceId;
    }

    /**
     * 供应商来源ID
     */
    public void setSupplierSourceId(java.lang.String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    /**
     * 退场日期
     */
    public java.util.Date getExitDate() {
        return exitDate;
    }

    /**
     * 退场日期
     */
    public void setExitDate(java.util.Date exitDate) {
        this.exitDate = exitDate;
    }
    /**
     * 确认日期
     */
    public java.util.Date getConfirmDate() {
        return confirmDate;
    }

    /**
     * 确认日期
     */
    public void setConfirmDate(java.util.Date confirmDate) {
        this.confirmDate = confirmDate;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 确认状态0-未确认1-已确认2-已拒绝
     */
    public java.lang.Integer getConfirmFlag() {
        return confirmFlag;
    }

    /**
     * 确认状态0-未确认1-已确认2-已拒绝
     */
    public void setConfirmFlag(java.lang.Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }
    /**
     * 经办人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 确认人
     */
    public java.lang.Long getConfirmerId() {
        return confirmerId;
    }

    /**
     * 确认人
     */
    public void setConfirmerId(java.lang.Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    /**
     * 确认人名称
     */
    public java.lang.String getConfirmerName() {
        return confirmerName;
    }

    /**
     * 确认人名称
     */
    public void setConfirmerName(java.lang.String confirmerName) {
        this.confirmerName = confirmerName;
    }
    /**
     * 退场说明
     */
    public java.lang.String getExitNote() {
        return exitNote;
    }

    /**
     * 退场说明
     */
    public void setExitNote(java.lang.String exitNote) {
        this.exitNote = exitNote;
    }
    /**
     * 确认说明
     */
    public java.lang.String getConfirmNote() {
        return confirmNote;
    }

    /**
     * 确认说明
     */
    public void setConfirmNote(java.lang.String confirmNote) {
        this.confirmNote = confirmNote;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }
    /**
     * 申请单ID
     */
    public java.lang.Long getApplyId() {
        return applyId;
    }

    /**
     * 申请单ID
     */
    public void setApplyId(java.lang.Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 保存状态（0-暂存态，1-保存态）
     */
    public java.lang.Integer getSaveState() {
        return saveState;
    }

    /**
     * 保存状态（0-暂存态，1-保存态）
     */
    public void setSaveState(java.lang.Integer saveState) {
        this.saveState = saveState;
    }
    /**
     * 推送NC状态，0-未推送，1-已推送
     */
    public java.lang.Integer getUseState() {
        return useState;
    }

    /**
     * 推送NC状态，0-未推送，1-已推送
     */
    public void setUseState(java.lang.Integer useState) {
        this.useState = useState;
    }
    /**
     * 推送人主键
     */
    public java.lang.Long getPushUserId() {
        return pushUserId;
    }

    /**
     * 推送人主键
     */
    public void setPushUserId(java.lang.Long pushUserId) {
        this.pushUserId = pushUserId;
    }
    /**
     * 推送人来源ID
     */
    public java.lang.String getPushUserSourceId() {
        return pushUserSourceId;
    }

    /**
     * 推送人来源ID
     */
    public void setPushUserSourceId(java.lang.String pushUserSourceId) {
        this.pushUserSourceId = pushUserSourceId;
    }
    /**
     * 推送人名称
     */
    public java.lang.String getPushUserName() {
        return pushUserName;
    }

    /**
     * 推送人名称
     */
    public void setPushUserName(java.lang.String pushUserName) {
        this.pushUserName = pushUserName;
    }
    /**
     * 是否补录，0-否，1-是
     */
    public java.lang.String getIsaddrecord() {
        return isaddrecord;
    }

    /**
     * 是否补录，0-否，1-是
     */
    public void setIsaddrecord(java.lang.String isaddrecord) {
        this.isaddrecord = isaddrecord;
    }
    /**
     * 补录原因
     */
    public java.lang.String getAddrcdreson() {
        return addrcdreson;
    }

    /**
     * 补录原因
     */
    public void setAddrcdreson(java.lang.String addrcdreson) {
        this.addrcdreson = addrcdreson;
    }
    
    /**
     * 退场单明细
     */
    public List<ExitDetailEntity> getExitDetail() {
        return exitDetail;
    }

    public void setExitDetail(List<ExitDetailEntity> exitDetail) {
        this.exitDetail = exitDetail;
    }
}

==> cscec5b-wzxt-impl-3.0.0-20210324.055833-187-sources.jar: com/ejianc/business/wzxt/bean/ExitEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.wzxt.bean.ExitDetailEntity;
/**
 * 退场单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_exit")
public class ExitEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目
    @TableField(value="project_source_id")
    private java.lang.String projectSourceId; // 项目来源ID
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_source_id")
    private java.lang.String orgSourceId; // 组织来源ID
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private java.lang.Long parentOrgId; // 上级组织
    @TableField(value="parent_org_source_id")
    private java.lang.String parentOrgSourceId; // 上级组织来源ID
    @TableField(value="contract_id")
    private java.lang.String contractId; // 合同主键
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 供应商名称
    @TableField(value="supplier_source_id")
    private java.lang.String supplierSourceId; // 供应商来源ID
    @TableField(value="exit_date")
    private java.util.Date exitDate; // 退场日期
    @TableField(value="confirm_date")
    private java.util.Date confirmDate; // 确认日期
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="confirm_flag")
    private java.lang.Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 经办人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 经办人名称
    @TableField(value="confirmer_id")
    private java.lang.Long confirmerId; // 确认人
    @TableField(value="confirmer_name")
    private java.lang.String confirmerName; // 确认人名称
    @TableField(value="exit_note")
    private java.lang.String exitNote; // 退场说明
    @TableField(value="confirm_note")
    private java.lang.String confirmNote; // 确认说明
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="def1")
    private java.lang.String def1; // 
    @TableField(value="def2")
    private java.lang.String def2; // 
    @TableField(value="def3")
    private java.lang.String def3; // 
    @TableField(value="def4")
    private java.lang.String def4; // 
    @TableField(value="def5")
    private java.lang.String def5; // 
    @TableField(value="apply_id")
    private java.lang.Long applyId; // 申请单ID
    @TableField(value="save_state")
    private java.lang.Integer saveState; // 保存状态（0-暂存态，1-保存态）
    @TableField(value="use_state")
    private java.lang.Integer useState; // 推送NC状态，0-未推送，1-已推送
    @TableField(value="push_user_id")
    private java.lang.Long pushUserId; // 推送人主键
    @TableField(value="push_user_source_id")
    private java.lang.String pushUserSourceId; // 推送人来源ID
    @TableField(value="push_user_name")
    private java.lang.String pushUserName; // 推送人名称
    @TableField(value="isaddrecord")
    private java.lang.String isaddrecord; // 是否补录，0-否，1-是
    @TableField(value="addrcdreson")
    private java.lang.String addrcdreson; // 补录原因
    @TableField(value="commit_id")
    private java.lang.Long commitId; // 提交人
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="exitDetailService",pidName = "exitId")
    private List<ExitDetailEntity> exitDetail = new ArrayList<>(); // 退场单明细

    public Long getCommitId() {
        return commitId;
    }

    public void setCommitId(Long commitId) {
        this.commitId = commitId;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目来源ID
     */
    public java.lang.String getProjectSourceId() {
        return projectSourceId;
    }

    /**
     * 项目来源ID
     */
    public void setProjectSourceId(java.lang.String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织来源ID
     */
    public java.lang.String getOrgSourceId() {
        return orgSourceId;
    }

    /**
     * 组织来源ID
     */
    public void setOrgSourceId(java.lang.String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织
     */
    public java.lang.Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织
     */
    public void setParentOrgId(java.lang.Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织来源ID
     */
    public java.lang.String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    /**
     * 上级组织来源ID
     */
    public void setParentOrgSourceId(java.lang.String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    /**
     * 合同主键
     */
    public java.lang.String getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(java.lang.String contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 设备供应商
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 供应商来源ID
     */
    public java.lang.String getSupplierSourceId() {
        return supplierSourceId;
    }

    /**
     * 供应商来源ID
     */
    public void setSupplierSourceId(java.lang.String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    /**
     * 退场日期
     */
    public java.util.Date getExitDate() {
        return exitDate;
    }

    /**
     * 退场日期
     */
    public void setExitDate(java.util.Date exitDate) {
        this.exitDate = exitDate;
    }
    /**
     * 确认日期
     */
    public java.util.Date getConfirmDate() {
        return confirmDate;
    }

    /**
     * 确认日期
     */
    public void setConfirmDate(java.util.Date confirmDate) {
        this.confirmDate = confirmDate;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 确认状态0-未确认1-已确认2-已拒绝
     */
    public java.lang.Integer getConfirmFlag() {
        return confirmFlag;
    }

    /**
     * 确认状态0-未确认1-已确认2-已拒绝
     */
    public void setConfirmFlag(java.lang.Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }
    /**
     * 经办人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 确认人
     */
    public java.lang.Long getConfirmerId() {
        return confirmerId;
    }

    /**
     * 确认人
     */
    public void setConfirmerId(java.lang.Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    /**
     * 确认人名称
     */
    public java.lang.String getConfirmerName() {
        return confirmerName;
    }

    /**
     * 确认人名称
     */
    public void setConfirmerName(java.lang.String confirmerName) {
        this.confirmerName = confirmerName;
    }
    /**
     * 退场说明
     */
    public java.lang.String getExitNote() {
        return exitNote;
    }

    /**
     * 退场说明
     */
    public void setExitNote(java.lang.String exitNote) {
        this.exitNote = exitNote;
    }
    /**
     * 确认说明
     */
    public java.lang.String getConfirmNote() {
        return confirmNote;
    }

    /**
     * 确认说明
     */
    public void setConfirmNote(java.lang.String confirmNote) {
        this.confirmNote = confirmNote;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }
    /**
     * 申请单ID
     */
    public java.lang.Long getApplyId() {
        return applyId;
    }

    /**
     * 申请单ID
     */
    public void setApplyId(java.lang.Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 保存状态（0-暂存态，1-保存态）
     */
    public java.lang.Integer getSaveState() {
        return saveState;
    }

    /**
     * 保存状态（0-暂存态，1-保存态）
     */
    public void setSaveState(java.lang.Integer saveState) {
        this.saveState = saveState;
    }
    /**
     * 推送NC状态，0-未推送，1-已推送
     */
    public java.lang.Integer getUseState() {
        return useState;
    }

    /**
     * 推送NC状态，0-未推送，1-已推送
     */
    public void setUseState(java.lang.Integer useState) {
        this.useState = useState;
    }
    /**
     * 推送人主键
     */
    public java.lang.Long getPushUserId() {
        return pushUserId;
    }

    /**
     * 推送人主键
     */
    public void setPushUserId(java.lang.Long pushUserId) {
        this.pushUserId = pushUserId;
    }
    /**
     * 推送人来源ID
     */
    public java.lang.String getPushUserSourceId() {
        return pushUserSourceId;
    }

    /**
     * 推送人来源ID
     */
    public void setPushUserSourceId(java.lang.String pushUserSourceId) {
        this.pushUserSourceId = pushUserSourceId;
    }
    /**
     * 推送人名称
     */
    public java.lang.String getPushUserName() {
        return pushUserName;
    }

    /**
     * 推送人名称
     */
    public void setPushUserName(java.lang.String pushUserName) {
        this.pushUserName = pushUserName;
    }
    /**
     * 是否补录，0-否，1-是
     */
    public java.lang.String getIsaddrecord() {
        return isaddrecord;
    }

    /**
     * 是否补录，0-否，1-是
     */
    public void setIsaddrecord(java.lang.String isaddrecord) {
        this.isaddrecord = isaddrecord;
    }
    /**
     * 补录原因
     */
    public java.lang.String getAddrcdreson() {
        return addrcdreson;
    }

    /**
     * 补录原因
     */
    public void setAddrcdreson(java.lang.String addrcdreson) {
        this.addrcdreson = addrcdreson;
    }
    
    /**
     * 退场单明细
     */
    public List<ExitDetailEntity> getExitDetail() {
        return exitDetail;
    }

    public void setExitDetail(List<ExitDetailEntity> exitDetail) {
        this.exitDetail = exitDetail;
    }
}
